program P2M

  use sep
  use utilities

  implicit none
  type(paxis) :: a1,a2
  complex, dimension(:,:), allocatable :: data !! picks and weights
  real,    dimension(:,:), allocatable :: fillmap
  real,    dimension(:,:), allocatable :: fillknw
  real,     dimension(:), allocatable  :: tmp
  logical, dimension(:,:), allocatable :: pick

  integer :: niter
  real    :: eps
  real    :: piktrust
  logical :: laplacian
  real    :: val
  integer :: i1,i2
  integer :: jl,ju
  integer :: ns

  !----------------------------------------------------------------  
  call sep_init()

  call from_param("niter",niter, 20)
  call from_param(  "eps",  eps,1.0)
  call from_param("piktrust",piktrust,.5)
  call from_param("laplacian",laplacian,.false.)
  call from_param("ns",ns,5)

  call pinaxis(a1,1)
  call pinaxis(a2,2)

  call to_history("esize",4)
  call sep_close()
  !----------------------------------------------------------------
  allocate( data(a1%n,a2%n))
  allocate(fillmap(a1%n,a2%n)); fillmap=0.
  allocate(fillknw(a1%n,a2%n)); fillknw=1.
  allocate(tmp(a1%n))
  allocate( pick(a1%n,a2%n))
  !----------------------------------------------------------------
  call sep_read(data)
  !----------------------------------------------------------------

  !! constrain picks at the surface
  fillmap(1,:)=1.

  fillmap =  real(data) !! picks
  fillknw = aimag(data) !! weights
  fillknw = piktrust

!  pick=.true.
!  where(fillmap==0) pick=.false.
!  where(.not. pick) fillmap=1.

  where(fillmap==0) fillmap=1

  !! vertical integration
  do i2=1,a2%n
     tmp = fillmap(:,i2)
     do i1=1,a1%n
!        if(.not.pick(i1,i2)) cycle
        if(tmp(i1)==1) cycle

           jl=i1-ns; jl=max(jl,1)
           ju=i1+ns; ju=min(ju,a1%n)

           fillmap(jl:ju,i2)=tmp(i1)

     end do
  end do

  fillmap(1,:)=1; fillmap(a1%n,:)=1.
  fillmap(:,1)=1; fillmap(:,a2%n)=1.

  !----------------------------------------------------------------
  call sep_write(fillmap)
  !----------------------------------------------------------------
  deallocate(fillmap,fillknw)
end program P2M




